@@ -1,4 +1,5 @@
 from .common_voice_dataset import CommonVoiceDataset
-from .ljspeech_dataset import LJSpeechDataset
+from .libri_speech_dataset import LibriSpeechDataset
+from .lj_speech_dataset import LJSpeechDataset
 from .wav_dataset import WAVDataset
 from .youtube_dataset import YoutubeDataset
